## ------------------------------------------------------------------------
getwd()

## ------------------------------------------------------------------------
ITSDaten <- read.csv2(file = "ITSDaten.csv")

## ------------------------------------------------------------------------
View(ITSDaten)

## ------------------------------------------------------------------------
str(ITSDaten)

## ------------------------------------------------------------------------
table(ITSDaten$OP)

## ------------------------------------------------------------------------
table(ITSDaten$OP)/nrow(ITSDaten)

## ------------------------------------------------------------------------
barplot(table(ITSDaten$OP))

## ------------------------------------------------------------------------
barplot(table(ITSDaten$OP), main = "Operationsarten",
        ylab = "Absolute Häufigkeiten")

## ------------------------------------------------------------------------
install.packages("ggplot2")

## ------------------------------------------------------------------------
library(ggplot2)

## ------------------------------------------------------------------------
## Anlegen der Daten
ggplot(ITSDaten, aes(x=OP)) +
  ## Hinzufügen der Balken für die relativen Häufigkeiten
  geom_bar(aes(y = 100*(..count..)/sum(..count..)), width = 0.5) +
  ## Titel und Beschriftung der y-Achse
  ggtitle("Operationsarten") + ylab("Relative Häufigkeit in %")

## ------------------------------------------------------------------------
pie(table(ITSDaten$OP), main = "Operationsarten")

## ------------------------------------------------------------------------
ceiling(2.01)
ceiling(3.88)

## ------------------------------------------------------------------------
## Aneinanderhängen von Zahlen zu einem Vektor
x <- c(2, 4, 6, 8, 10, 12, 14, 16, 18, 20)
## Zahlenfolge: Beginn = 2, Ende = 20, Abstand = 2
x <- seq(from = 2, to = 20, by = 2)

## ------------------------------------------------------------------------
x
## R default
quantile(x, probs = 0.2)
## Von SAS Software verwendet
quantile(x, type = 3, probs = 0.2)
## Von SPSS und Minitab Software verwendet
quantile(x, type = 6, probs = 0.2)

## ------------------------------------------------------------------------
median(ITSDaten$SAPS.II)
## alternativ auch möglich
quantile(ITSDaten$SAPS.II, probs = 0.5)

## ------------------------------------------------------------------------
IQR(ITSDaten$SAPS.II)

## ------------------------------------------------------------------------
M <- median(ITSDaten$SAPS.II)
median(abs(ITSDaten$SAPS.II-M))

## ------------------------------------------------------------------------
mad(ITSDaten$SAPS.II)

## ------------------------------------------------------------------------
mad(ITSDaten$SAPS.II, constant = 1)

## ------------------------------------------------------------------------
## Anlegen der Daten
ggplot(ITSDaten, aes(x=SAPS.II)) +
  ## Hinzufügen der Balken
  geom_bar(aes(y = 100*(..count..)/sum(..count..))) +
  ## Titel und Beschriftung der y-Achse
  ggtitle("SAPS II") + ylab("Relative Häufigkeit in %")

## ------------------------------------------------------------------------
boxplot(ITSDaten$SAPS.II, main = "500 ITS Patienten", ylab = "SAPS II Score")

## ------------------------------------------------------------------------
## Box-und-Whisher Plot an der Stelle x = 1
qplot(x = 1, y = SAPS.II, data = ITSDaten, geom = "boxplot",
      xlim = c(0, 2), main = "500 ITS Patienten", ylab = "SAPS II Score")

## ------------------------------------------------------------------------
x <- c(2, 4, 6, 8, 10, 12, 14, 16, 18, 20)
quantile(x, probs = c(0.5, 0.75, 0.9, 0.95))

## ------------------------------------------------------------------------
x <- c(2, 4, 6, 8, 10, 12, 14, 16, 18, 200)
quantile(x, probs = c(0.5, 0.75, 0.9, 0.95))

## ------------------------------------------------------------------------
plot(ecdf(ITSDaten$SAPS.II), main = "Empirische Verteilungsfunktion",
     xlab = "SAPS II", do.points = FALSE)

## ------------------------------------------------------------------------
qplot(ITSDaten$SAPS.II, stat = "ecdf", geom = "step", xlab = "SAPS II",
      ylab = "Fn(x)", main = "Empirische Verteilungsfunktion")

## ------------------------------------------------------------------------
table(ITSDaten$Geschlecht, ITSDaten$OP)

## ------------------------------------------------------------------------
prop.table(table(ITSDaten$Geschlecht, ITSDaten$OP), margin = 1)

## ------------------------------------------------------------------------
round(100*prop.table(table(ITSDaten$Geschlecht, ITSDaten$OP), margin = 1), 1)

## ------------------------------------------------------------------------
install.packages("DescTools")

## ------------------------------------------------------------------------
library(DescTools)
PercTable(table(ITSDaten$Geschlecht, ITSDaten$OP), rfrq = "010", pfmt = TRUE,
          digits = 1)

## ------------------------------------------------------------------------
## phi-Koeffizient
Phi(table(ITSDaten$Geschlecht, ITSDaten$OP))
## Pearsons Kontingenzkoeffizient
ContCoef(table(ITSDaten$Geschlecht, ITSDaten$OP))
## Cramers V
CramerV(table(ITSDaten$Geschlecht, ITSDaten$OP))

## ------------------------------------------------------------------------
barplot(prop.table(table(ITSDaten$Geschlecht, ITSDaten$OP), margin = 1),
        beside = TRUE, legend.text = TRUE, ylab = "Relative Häufigkeit",
        main = "Geschlecht und Art der OP")

## ------------------------------------------------------------------------
## Spearmans rho
cor(ITSDaten$SAPS.II, ITSDaten$LOS, method = "spearman")
## Kendalls tau
cor(ITSDaten$SAPS.II, ITSDaten$LOS, method = "kendall")

## ------------------------------------------------------------------------
plot(ITSDaten$SAPS.II, ITSDaten$LOS, xlab = "SAPS II", ylab = "LOS",
     main = "SAPS II und LOS")

## ------------------------------------------------------------------------
ggplot(ITSDaten, aes(x=SAPS.II, y=LOS)) +
  ## shape = 19: etwas größerer Punkt
  ## alpha = 0.25: Stärke des Blendings
  geom_point(shape=19, alpha=0.25) +
  ## Beschriftung
  ggtitle("SAPS II und LOS") + xlab("SAPS II") + ylab("LOS")

## ------------------------------------------------------------------------
mean(ITSDaten$Temperatur)

## ------------------------------------------------------------------------
round(mean(ITSDaten$Temperatur), 1)

## ------------------------------------------------------------------------
median(ITSDaten$Temperatur)

## ------------------------------------------------------------------------
round(mean(ITSDaten$LOS),1)
median(ITSDaten$LOS)

## ------------------------------------------------------------------------
log(Gmean(ITSDaten$Bilirubin))

## ------------------------------------------------------------------------
mean(log(ITSDaten$Bilirubin))

## ------------------------------------------------------------------------
exp(mean(log(ITSDaten$Bilirubin)))

## ------------------------------------------------------------------------
var(ITSDaten$Temperatur)
sd(ITSDaten$Temperatur)

## ------------------------------------------------------------------------
n <- nrow(ITSDaten)
(n-1)/n*var(ITSDaten$Temperatur)
(n-1)/n*sd(ITSDaten$Temperatur)

## ------------------------------------------------------------------------
sd(ITSDaten$Temperatur)
mad(ITSDaten$Temperatur)

## ------------------------------------------------------------------------
sd(ITSDaten$Temperatur)/mean(ITSDaten$Temperatur)
mad(ITSDaten$Temperatur)/median(ITSDaten$Temperatur)
IQR(ITSDaten$Temperatur)/median(ITSDaten$Temperatur)

## ------------------------------------------------------------------------
log(Gsd(ITSDaten$Bilirubin))
sd(log(ITSDaten$Bilirubin))

## ------------------------------------------------------------------------
Skew(ITSDaten$Temperatur)

## ------------------------------------------------------------------------
## Patient 398
ITSDaten$Temperatur[398]

## ------------------------------------------------------------------------
Skew(ITSDaten$Temperatur[-398])

## ------------------------------------------------------------------------
sd(ITSDaten$Temperatur[-398])

## ------------------------------------------------------------------------
Skew(ITSDaten$LOS)

## ------------------------------------------------------------------------
Kurt(ITSDaten$Temperatur)
Kurt(ITSDaten$Temperatur[-398])

## ------------------------------------------------------------------------
Kurt(ITSDaten$LOS)

## ------------------------------------------------------------------------
## Box-und-Whisker Plot an der Stelle x = 1
qplot(x = 1, y = Temperatur, data = ITSDaten, geom = "boxplot",
      xlim = c(0, 2), main = "500 ITS Patienten",
      ylab = "Maximale Körpertemperatur")

## ------------------------------------------------------------------------
hist(ITSDaten$Temperatur, breaks = seq(from = 9.0, to = 42, by = 0.5),
     main = "500 ITS Patienten", xlab = "Maximale Körpertemperatur",
     ylab = "Absolute Häufigkeit")

## ------------------------------------------------------------------------
hist(ITSDaten$Temperatur, breaks = seq(from = 9.0, to = 42, by = 0.5),
     main = "500 ITS Patienten", xlab = "Maximale Körpertemperatur",
     ylab = "Absolute Häufigkeit", xlim = c(33,43))

## ------------------------------------------------------------------------
qplot(LOS, data = ITSDaten, geom = "histogram", binwidth = 1,
      xlab = "Aufenthaltsdauer in Tagen", ylab = "Absolute Häufigkeit",
      main = "500 ITS Patienten")

## ------------------------------------------------------------------------
plot(density(ITSDaten$Temperatur[-398]), xlab = "Maximale Körpertemperatur",
     ylab = "Dichte", main = "500 ITS Patienten")

## ------------------------------------------------------------------------
hist(ITSDaten$Temperatur[-398], breaks = seq(from = 33, to = 42, by = 0.5),
     xlab = "Maximale Körpertemperatur", ylab = "Dichte", freq = FALSE,
     main = "500 ITS Patienten")
lines(density(ITSDaten$Temperatur[-398]))

## ------------------------------------------------------------------------
ggplot(ITSDaten[-398,], aes(x=Temperatur)) +
  geom_histogram(aes(y=..density..), binwidth = 0.5) +
  geom_density(color = "orange") + ylab("Dichte") +
  xlab("Maximale Körpertemperatur") +
  ggtitle("500 ITS Patienten")

## ------------------------------------------------------------------------
ggplot(ITSDaten[-398,], aes(x=Temperatur)) +
  geom_histogram(aes(y=..density..), binwidth = 0.5, right = TRUE) +
  geom_density(color = "orange") + ylab("Dichte") +
  xlab("Maximale Körpertemperatur") +
  ggtitle("500 ITS Patienten")

## ------------------------------------------------------------------------
plot(ecdf(ITSDaten$Temperatur[-398]), main = "Empirische Verteilungsfunktion",
     xlab = "Maximale Körpertemperatur", do.points = FALSE)

## ------------------------------------------------------------------------
qplot(ITSDaten$Temperatur[-398], stat = "ecdf", geom = "step",
      xlab = "Maximale Körpertemperatur", ylab = "Fn(x)",
      main = "Empirische Verteilungsfunktion")

## ------------------------------------------------------------------------
cor(ITSDaten$Temperatur, ITSDaten$Herzfrequenz)

## ------------------------------------------------------------------------
ggplot(ITSDaten, aes(x=Temperatur, y=Herzfrequenz)) +
  ## shape = 19: etwas größerer Punkt
  ## alpha = 0.25: Stärke des Blendings
  geom_point(shape=19, alpha=0.25) +
  ## Beschriftung
  ggtitle("500 ITS Patienten") + xlab("Maximale Körpertemperatur") +
  ylab("Maximale Herzfrequenz")

## ------------------------------------------------------------------------
cor(ITSDaten$Temperatur[-398], ITSDaten$Herzfrequenz[-398])

## ------------------------------------------------------------------------
## Spearmans rho
cor(ITSDaten$Temperatur, ITSDaten$Herzfrequenz, method = "spearman")
cor(ITSDaten$Temperatur[-398], ITSDaten$Herzfrequenz[-398], method = "spearman")
## Kendalls tau
cor(ITSDaten$Temperatur, ITSDaten$Herzfrequenz, method = "kendall")
cor(ITSDaten$Temperatur[-398], ITSDaten$Herzfrequenz[-398], method = "kendall")

## ------------------------------------------------------------------------
ggplot(ITSDaten[-398,], aes(x=Temperatur, y=Herzfrequenz)) +
  ## shape = 19: etwas größerer Punkt
  ## alpha = 0.25: Stärke des Blendings
  geom_point(shape=19, alpha=0.25) +
  ## Beschriftung
  ggtitle("500 ITS Patienten") + xlab("Maximale Körpertemperatur") +
  ylab("Maximale Herzfrequenz")
