## ------------------------------------------------------------------------
install.packages("RColorBrewer")

## ------------------------------------------------------------------------
library(RColorBrewer)
display.brewer.all(type = "qual")

## ------------------------------------------------------------------------
display.brewer.all(type = "seq")

## ------------------------------------------------------------------------
display.brewer.all(type = "div")

## ------------------------------------------------------------------------
## n = 5 Farben der Palette mit Namen Set1
farben <- brewer.pal(n = 5, name = "Set1")
farben

## ------------------------------------------------------------------------
rgb(red = 228, green = 26, blue = 28, maxColorValue = 255)

## ------------------------------------------------------------------------
col2rgb("royalblue")

## ------------------------------------------------------------------------
barplot(table(ITSDaten$OP), main = "Operationsarten",
        ylab = "Absolute Häufigkeiten", col = farben)

## ------------------------------------------------------------------------
## Anlegen der Daten
ggplot(ITSDaten, aes(x=OP)) +
  ## Hinzufügen der Balken für die relativen Häufigkeiten
  geom_bar(aes(y = 100*(..count..)/sum(..count..)), width = 0.5,
           ## Füllen der Balken
           fill = farben) +
  ## Titel und Beschriftung der y-Achse
  ggtitle("Operationsarten") + ylab("Relative Häufigkeit in %")

## ------------------------------------------------------------------------
## 1. Öffnen des Grafikgerätes png
## height und width in Pixel
png(file = "Beispiel_Bild.png", height = 640, width = 640)
## 2. Erzeugen des Plots
barplot(table(ITSDaten$OP), main = "Operationsarten",
        ylab = "Absolute Häufigkeiten", col = farben)
## 3. Beenden des Grafikgerätes
dev.off()

## ------------------------------------------------------------------------
farben <- brewer.pal(n = 5, name = "Set3")
boxplot(SAPS.II ~ OP, data = ITSDaten, ylab = "SAPS II",
        main = "SAPS II in Abhängigkeit von der OP Art", col = farben)

## ------------------------------------------------------------------------
## Anlegen der Daten
ggplot(ITSDaten, aes(x = OP, y = SAPS.II)) +
  ## Box-und-Whisker Plot mit den vorgegeben Farben
  geom_boxplot(fill = farben) +
  ## Beschriftung
  ylab("SAPS II") + ggtitle("SAPS II in Abhängigkeit von der OP Art")

## ------------------------------------------------------------------------
farben1 <- rev(brewer.pal(5, "Blues"))
farben2 <- rep("#31A354", 3)
farben3 <- brewer.pal(9, "Reds")
hist(ITSDaten$Temperatur[-398], breaks = seq(from = 33.5, to = 42, by = 0.5),
     main = "500 ITS Patienten", ylab = "Absolute Häufigkeit",
     xlab = "Maximale Körpertemperatur", col = c(farben1, farben2, farben3))

## ------------------------------------------------------------------------
farben1 <- c(farben1[1], farben1)
farben3 <- c(farben3, farben3[9])
ggplot(ITSDaten[-398,], aes(x=Temperatur)) +
  geom_histogram(binwidth = 0.5, right = TRUE,
                 fill = c(farben1, farben2, farben3))+
  ylab("Absolute Häufigkeit") + xlab("Maximale Körpertemperatur") +
  ggtitle("500 ITS Patienten")

## ------------------------------------------------------------------------
## Anlegen eines leeren Vektors
farbenGeschlecht <- character(nrow(ITSDaten))
## Auffüllen mit Farben
farbenGeschlecht[ITSDaten$Geschlecht == "weiblich"] <- "#67000D"
farbenGeschlecht[ITSDaten$Geschlecht == "männlich"] <- "#08519C"

## ------------------------------------------------------------------------
plot(x = ITSDaten$Temperatur, y = ITSDaten$Herzfrequenz, pch = 19,
     xlab = "Maximal Körpertemperatur", ylab = "Maximale Herzfrequenz",
     main = "500 ITS Patienten",
     col = farbenGeschlecht, xlim = c(33,43))
legend(x = "topleft", legend = c("weiblich", "männlich"), pch = 19,
       col = c("#67000D", "#08519C"))

## ------------------------------------------------------------------------
ggplot(ITSDaten[-398,], aes(x=Temperatur, y=Herzfrequenz, colour=Geschlecht)) +
  ## shape = 19: etwas größerer Punkt
  ## alpha = 0.4: Stärke des Blendings
  geom_point(shape=19, alpha=0.4) +
  ## Werte für die Farbgebung
  scale_colour_manual(values = c("#08519C", "#67000D")) +
  ## Beschriftung
  ggtitle("500 ITS Patienten") + xlab("Maximale Körpertemperatur") +
  ylab("Maximale Herzfrequenz")
