## ------------------------------------------------------------------------
## biasfrei und effizient
table(ITSDaten$Leberversagen)/nrow(ITSDaten)

## ------------------------------------------------------------------------
## biasfrei und effizient
mean(ITSDaten$Temperatur[-398])
## biasfrei
sd(ITSDaten$Temperatur[-398])

## ------------------------------------------------------------------------
pnorm(10, mean = 37.7, sd = 1.2)

## ------------------------------------------------------------------------
library(MASS)
fitdistr(ITSDaten$Temperatur[-398], densfun = "normal")

## ------------------------------------------------------------------------
install.packages("distrMod")

## ------------------------------------------------------------------------
library(distrMod)
## Anlegen des Modells
Modell <- NormLocationScaleFamily()
## ML-Schätzung
MLEstimator(ITSDaten$Temperatur[-398], Modell)

## ------------------------------------------------------------------------
hist(ITSDaten$Temperatur[-398], breaks = seq(from = 33, to = 42, by = 0.5),
     main = "Maximale Körpertemperatur", ylab = "Dichte", freq = FALSE)
lines(density(ITSDaten$Temperatur[-398]))
curve(dnorm(x, mean = 37.7, sd = 1.2), col = "darkred", from = 33, to = 42,
      n = 501, add = TRUE, lwd = 2)
legend("topright", fill = "darkred", legend = "Geschätztes Modell")

## ------------------------------------------------------------------------
ggplot(ITSDaten[-398,], aes(x=Temperatur)) +
  geom_histogram(aes(y=..density..), binwidth = 0.5, right = TRUE,
                 fill = "darkgrey") +
  geom_density(color = "orange") + ylab("Dichte") +
  stat_function(fun = dnorm, args = list(mean = 37.7, sd = 1.2),
                color = "darkred", lwd = 2) +
  annotate("text", x = 40, y = 0.31, col = "darkred",
           label = "Geschätztes Modell")+
  ggtitle("Maximale Körpertemperatur")

## ------------------------------------------------------------------------
qqnorm(ITSDaten$Temperatur[-398], main = "qq-Plot für die Normalverteilung",
       ylab = "Maximale Körpertemperatur")
qqline(ITSDaten$Temperatur[-398])

## ------------------------------------------------------------------------
qqplot(ITSDaten$Temperatur[-398], Norm(mean = 37.7, sd = 1.2),
       xlab = "Maximale Körpertemperatur",
       main = "qq-Plot für Norm(37.7, 1.2)")

## ------------------------------------------------------------------------
par(mfrow=c(3,3))
for(i in 1:9){
  x <- rnorm(499)
  qqnorm(x)
  qqline(x)
}

## ------------------------------------------------------------------------
median(ITSDaten$Temperatur)
mad(ITSDaten$Temperatur)

## ------------------------------------------------------------------------
Modell <- NormLocationScaleFamily()
MDEstimator(ITSDaten$Temperatur[-398], Modell, distance = CvMDist)

## ------------------------------------------------------------------------
MDEstimator(ITSDaten$Temperatur[-398], Modell, distance = KolmogorovDist)

## ------------------------------------------------------------------------
## Ausgabeoption ändern
distrModOptions(show.details = "minimal")
## ML-Schätzer
MLEstimator(ITSDaten$Temperatur, Modell)
## CvM-MD-Schätzer
MDEstimator(ITSDaten$Temperatur, Modell, distance = CvMDist)
## KS-MD-Schätzer
MDEstimator(ITSDaten$Temperatur, Modell, distance = KolmogorovDist)
## Ausgabeoption wieder zurücksetzen auf default
distrModOptions(show.details = "maximal")

## ------------------------------------------------------------------------
## Arithmetisches Mittel
AM <- mean(ITSDaten$Temperatur[-398])
AM
## Standardabweichung
SD <- sd(ITSDaten$Temperatur[-398])
SD
## alpha
alpha <- 0.05
alpha
## Stichprobengröße
n <- nrow(ITSDaten)-1
n
## Untere Konfidenzgrenze
AM - qt(1-alpha/2, df = n-1)*SD/sqrt(n)
## Obere Konfidenzgrenze
AM + qt(1-alpha/2, df = n-1)*SD/sqrt(n)

## ------------------------------------------------------------------------
t.test(ITSDaten$Temperatur[-398])$conf.int

## ------------------------------------------------------------------------
qt(1-alpha/2, df = n-1)
qnorm(1-alpha/2)

## ------------------------------------------------------------------------
## Untere Konfidenzgrenze
AM - qnorm(1-alpha/2)*SD/sqrt(n)
## Obere Konfidenzgrenze
AM + qnorm(1-alpha/2)*SD/sqrt(n)

## ------------------------------------------------------------------------
library(MASS)
## ML-Schätzer
ML <- fitdistr(ITSDaten$Temperatur[-398], densfun = "normal")
## Approximatives Konfidenzintervall
confint(ML)

## ------------------------------------------------------------------------
library(distrMod)
## Modell
Modell <- NormLocationScaleFamily()
## ML-Schäter
ML2 <- MLEstimator(ITSDaten$Temperatur[-398], Modell)
## Approximatives Konfidenzintervall
confint(ML2)

## ------------------------------------------------------------------------
## Untere Konfidenzgrenze
sqrt((n-1)*SD^2/qchisq(1-alpha/2, df = n-1))
## Obere Konfidenzgrenze
sqrt((n-1)*SD^2/qchisq(alpha/2, df = n-1))

## ------------------------------------------------------------------------
install.packages("MKmisc")

## ------------------------------------------------------------------------
library(MKmisc)
## Häufigkeit von Leberversagen
table(ITSDaten$Leberversagen)
## Clopper-Pearson-Intervall
binomCI(x = 20, n = 500, method = "clopper-pearson")
## Agresti-Coull-Intervall
binomCI(x = 20, n = 500, method = "agresti-coull")

## ------------------------------------------------------------------------
## Relative Häufigkeit
p <- 20/500
## Stichprobengröße
n <- 500
## alpha
alpha <- 0.05
## Untere Konfidenzgrenze
p + 1/(2*n) - qnorm(1-alpha/2)*sqrt(p*(1-p)/n)
## Obere Konfidenzgrenze
p - 1/(2*n) + qnorm(1-alpha/2)*sqrt(p*(1-p)/n)

## ------------------------------------------------------------------------
## Minimale Ausgabe
distrModOptions(show.details = "minimal")
## Bernoulli-Modell
Modell <- BinomFamily(size = 1)
## ML-Schätzer
MLp <- MLEstimator(ITSDaten$Leberversagen, Modell)
MLp
## Konfidenzintervall
confint(MLp)
## Zurücksetzen der Ausgabe auf default
distrModOptions(show.details = "maximal")

## ------------------------------------------------------------------------
## Exaktes Konfidenzintervall für den Median
medianCI(ITSDaten$Temperatur)
## Exaktes Konfidenzintervall für den MAD
M <- median(ITSDaten$Temperatur)
medianCI(1.4826*abs(ITSDaten$Temperatur - M))

## ------------------------------------------------------------------------
## Asymptotisches Konfidenzintervall für den Median
medianCI(ITSDaten$Temperatur, method = "asymptotic")
## Asymptotisches Konfidenzintervall für den MAD
medianCI(1.4826*abs(ITSDaten$Temperatur - M), method = "asymptotic")

## ------------------------------------------------------------------------
## Minimale Ausgabe
distrModOptions("show.details" = "minimal")
## Modell
Modell <- NormLocationScaleFamily()
## CvM-MD-Schätzer inkl. Varianz
MD <- MDEstimator(ITSDaten$Temperatur, Modell,
                  asvar.fct = distrMod:::.CvMMDCovariance)
## 95%-Konfidenzintervall
confint(MD)

## ------------------------------------------------------------------------
## Modell
Modell <- BinomFamily(size = 1)
## CvM-MD-Schätzer inkl. Varianz
MDp <- MDEstimator(ITSDaten$Leberversagen, Modell,
                  asvar.fct = distrMod:::.CvMMDCovariance)
## 95%-Konfidenzintervall
confint(MDp)
## Zurücksetzen auf default
distrModOptions("show.details" = "maximal")

## ------------------------------------------------------------------------
qnorm(0.975)

## ------------------------------------------------------------------------
## Werte für p
p <- seq(from = 0.01, to = 0.99, length = 100)
## Standardabweichung
SD <- sqrt(p*(1-p))
## Graphische Darstellung
qplot(p, SD, ylab = "sqrt(p*(1-p))", xlab = "p", geom = "line",
      main = "Standardabweichung von Bernoulli(p)")

## ------------------------------------------------------------------------
## Stichprobengröße
n <- seq(60, 10000, by = 20)
## Maximaler Schätzfehler
maxFehler <- 97.5/sqrt(n)
## Graphische Darstellung
qplot(n, maxFehler, geom = "line", xlab = "Stichprobengröße",
     ylab = "Prozent [%]", main = "Maximaler Schätzfehler")

